cumulusci.tasks.tests package
=============================

Submodules
----------

cumulusci.tasks.tests.test_command module
-----------------------------------------

.. automodule:: cumulusci.tasks.tests.test_command
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.tests.test_salesforce module
--------------------------------------------

.. automodule:: cumulusci.tasks.tests.test_salesforce
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.tests.test_sfdx module
--------------------------------------

.. automodule:: cumulusci.tasks.tests.test_sfdx
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.tests
    :members:
    :undoc-members:
    :show-inheritance:
